Chip

Enum Chip 

pub enum Chip {
    Esp32,
    Esp32c2,
    Esp32c3,
    Esp32c5,
    Esp32c6,
    Esp32c61,
    Esp32h2,
    Esp32s2,
    Esp32s3,
}
Available on crate feature build-script only.

Variants



Esp32



Esp32c2



Esp32c3



Esp32c5



Esp32c6



Esp32c61



Esp32h2



Esp32s2



Esp32s3

Implementations

Source

impl Chip

pub fn from_cargo_feature() -> Result<Self, &'static str>

Tries to extract the active chip from the active cargo features.

Exactly one device feature must be enabled for this function to succeed.

pub fn is_xtensa(self) -> bool

Returns whether the current chip uses the Tensilica Xtensa ISA.

pub fn target(self) -> &'static str

The target triple of the current chip.

pub fn name(self) -> &'static str

The simple name of the current chip.

Example
assert_eq!(Chip::Esp32s3.name(), "esp32s3");
pub fn contains(self, symbol: &str) -> bool

Returns whether the chip configuration contains the given symbol.

This function is a short-hand for self.all_symbols().contains(&symbol).

Example
assert!(Chip::Esp32s3.contains("soc_has_pcnt"));
pub fn define_cfgs(self)

Calling this function will define all cfg symbols for the firmware crate to use.

pub fn all_symbols(&self) -> &'static [&'static str]

Returns all symbols as a big slice.

Example
assert!(Chip::Esp32s3.all_symbols().contains("soc_has_pcnt"));
pub fn memory_layout(&self) -> &'static MemoryLayout

Returns memory layout information.

pub fn pins(&self) -> &'static [PinInfo]

Returns information about all pins.

pub fn iter() -> impl Iterator<Item = Chip>

Returns an iterator over all chips.

Example
assert!(Chip::iter().any(|c| c == Chip::Esp32));